% ########################################################################
%  ATTENTION
% ########################################################################
%
%  This software is for guidance only. It is provided "as is".
%  It only aims at providing coding information to the customer in order
%  for them to save time. As a result no warranties, whether express, 
%  implied or statutory, including, but not limited to implied warranties 
%  of merchantability and fitness for a particular purpose apply 
%  to this software.
%  A·P·E Angewandte Physik und Elektronik GmbH shall not be held liable 
%  for any direct, indirect or consequential damages with respect to any 
%  claims arising from the content of such sourcecode and/or the use made 
%  by customers of the coding information contained herein in connection
%  with their products.
%
%  File Version: 1.0
%
%  Changelog:
%    1.0 - Initial Version
%
% ########################################################################

function [x,y] = scpi_to_dbl_array(scpi_block_data)
    % SCPI_TO_DBL_ARRAY Converts the binary data from an SCPI block into 
    % an array of double values
    %
    % [x,y] = SCPI_TO_DBL_ARRAY(binary_data) Unpacks the binary data into 
    % two double-arrays for the x- and y-values 

    %each double value consists of 8 character values (=8bytes)
    % -> total number of values in binary data => nr_bytes / 8bytes
    array_elements = length(scpi_block_data)/8;

    %buffer for unpacked double values 
    % we're preallocating the array to improve the execution speed
    buffer_double = zeros(1,array_elements);

    read_offs = 1;
    
    for i = 1:array_elements
        %8 chars in the binary data represent one double value
        raw_data = scpi_block_data(read_offs:read_offs+7);

        %convert char-array to double value and set value in buffer array
        buffer_double(i) = typecast(raw_data, 'double');

        %increment read-offset for next iteration
        read_offs = i*8+1;
    end
    
    % odd elements indices in the new array are wavelength-values, 
    % the other ones are intensity values
    x = buffer_double(1:2:end);
    y = buffer_double(2:2:end);
end